<template>
	<view class="customer-my">
		<view class="huodai">
			<combined-title title="我的货代" @rightText="addHuoDai">
				<template v-slot:rightText>
					<text>添加</text>
				</template>
			</combined-title>
			<view class="huodai-list">
				<u-swipe-action>
					<u-cell-group :border="false">
						<u-swipe-action-item :options="options1" v-for="(item, index) in huoDaiData" :index="index" :name="item.userId" :key="index" @click="deleteHuoDaiClick">
							<u-cell :title="item.name" value="详情" @click="toFreightForwarderDetails(item.id)"></u-cell>
						</u-swipe-action-item>
					</u-cell-group>
				</u-swipe-action>
			</view>
		</view>
		<view class="fleet-container">
			<combined-title title="我的车队" @rightText="addFleet">
				<template v-slot:rightText>
					<text>添加</text>
				</template>
			</combined-title>
			<view class="fleet-list">
				<u-swipe-action>
					<u-cell-group :border="false">
						<u-swipe-action-item :options="options1" v-for="(item, index) in fleetData" :index="index" :name="item.id" :key="index" @click="deleteFleetClick">
							<u-cell :title="item.name" :value="item.userSijisum + '辆'" @click="tofleetDetails(item.id)"></u-cell>
						</u-swipe-action-item>
					</u-cell-group>
				</u-swipe-action>
			</view>
		</view>

		<view class="logout"><u-button text="退出登录" type="primary" @click="logout()"></u-button></view>

		<!-- 新建车队弹出框 -->
		<view class="addNewGroup">
			<u-popup :show="updateGroupShow" @close="addNewFleetPopupClose" @open="addNewFleetPopupOpen" mode="center">
				<view class="title"><u--text text="新建车队" size="30" lineHeight="80" align="center"></u--text></view>
				<view class="addCarForm">
					<u--form labelPosition="left" :model="addGroupForm" ref="form1" labelAlign="center">
						<u-form-item label="组名" borderBottom ref="groupName" labelWidth="100">
							<u--input v-model="addGroupForm.name" border="none" placeholder="请输入车队名称"></u--input>
						</u-form-item>
						<!-- <u-form-item label="车牌" borderBottom ref="cars" labelWidth="80">
              <u--textarea maxlength="2000" v-model="addGroupForm.carNums" placeholder="请输入车牌" height="150"></u--textarea>
            </u-form-item> -->
					</u--form>
				</view>
				<view class="addCarButton"><u-button text="添加" type="primary" @click="addNewGroupClick"></u-button></view>
			</u-popup>
		</view>

		<!-- 删除货代模态框 -->
		<view class="deleteHuoDaiModal">
			<u-modal
				:show="deleteHuoDaiShow"
				:title="deleteHuoDaiTitle"
				@close="deleteHuoDaiClose"
				@cancel="deleteHuoDaiCancel"
				@confirm="deleteHuoDaiConfirm"
				:closeOnClickOverlay="true"
				:showCancelButton="true"
			>
				<view class="slot-content"><rich-text :nodes="deleteHuoDaiContent"></rich-text></view>
			</u-modal>
		</view>
		<!-- 删除车队模态框 -->
		<view class="deleteFleetModal">
			<u-modal
				:show="deleteFleetShow"
				:title="deleteFleetTitle"
				@close="deleteFleetClose"
				@cancel="deleteFleetCancel"
				@confirm="deleteFleetConfirm"
				:closeOnClickOverlay="true"
				:showCancelButton="true"
			>
				<view class="slot-content"><rich-text :nodes="deleteFleetContent"></rich-text></view>
			</u-modal>
		</view>

		<view class="logoutModel">
			<u-modal :show="logoutShow" :title="logoutTitle" showCancelButton :content="logoutContent" @confirm="logoutConfirm" @cancel="logoutCancel"></u-modal>
		</view>
	</view>
</template>

<script>
import combinedTitle from '@/components/combined-title/combined-title.vue';
import { customerId, redirectLogin } from '@/utils/status';
export default {
	components: {
		combinedTitle
	},
	data() {
		return {
			huoDaiData: [],
			fleetData: [],
			// 新建车队
			addGroupForm: {
				customerId,
				name: ''
			},
			updateGroupShow: false,
			options1: [
				{
					text: '删除'
				}
			],
			// 删除货代模态框
			deleteHuoDaiId: null, // 删除货代id
			deleteHuoDaiShow: false,
			deleteHuoDaiTitle: '',
			deleteHuoDaiContent: '',
			// 删除车队模态框
			deleteFleetId: null, // 删除车队id
			deleteFleetShow: false,
			deleteFleetTitle: '',
			deleteFleetContent: '',
			// 退出模态框
			logoutShow: false,
			logoutTitle: '提示',
			logoutContent: '是否确认退出'
		};
	},
	onShow() {
		this.init();
	},
	methods: {
		init() {
			uni.showLoading({
				title: '加载中...'
			});
			this.getAllHuoDaiByCustomerId();
			this.getFleet();
			uni.hideLoading();
		},
		// 获取货代列表
		getAllHuoDaiByCustomerId() {
			this.$reqGet('getAllHuoDaiByCustomerId').then(res => {
				this.huoDaiData = res.data;
				console.log('货代列表', res);
			});
		},
		// 获取车队列表
		getFleet() {
			this.$reqGet('getFleet').then(res => {
				this.fleetData = res.data;
				console.log('车队列表', res);
			});
		},
		// 添加货代
		addHuoDai() {
			uni.navigateTo({
				url: '/pages/customer-page/addTo-freightForwarder-driver/addTo-freightForwarder-driver?role=1' // 1代表的是货代
			});
		},
		// 添加车队
		addFleet() {
			console.log('添加车队');
			this.updateGroupShow = true;
		},
		addNewFleetPopupClose() {
			this.updateGroupShow = false;
		},
		addNewFleetPopupOpen() {
			console.log('添加车队打开');
		},
		// 确认新建车队按钮
		addNewGroupClick() {
			uni.showLoading({
				title: '加载中...'
			});
			// 新建车队
			this.$reqPost('saveFleet', this.addGroupForm, 'params').then(res => {
				uni.hideLoading();
				if (res.code == 0) {
					this.$u.toast('添加成功');
					this.getFleet();
				} else {
					this.$u.toast(res.data ? res.data : '添加失败');
				}
			});
			this.updateGroupShow = false;
		},
		// 删除货代
		deleteHuoDaiClick(args) {
			console.log(args, '货代id');
			this.deleteHuoDaiId = args.name;
			this.deleteHuoDaiShow = true;
			this.huoDaiData.forEach(item => {
				if (item.userId == this.deleteHuoDaiId) {
					this.deleteHuoDaiContent = '确认删除货代' + item.name + '吗？';
				}
			});
		},
		deleteHuoDaiClose() {
			this.deleteHuoDaiShow = false;
		},
		deleteHuoDaiCancel() {
			this.deleteHuoDaiShow = false;
		},
		deleteHuoDaiConfirm() {
			this.deleteHuoDaiShow = false;
			uni.showLoading({
				title: '加载中...'
			});
			this.$reqPost('deleteHuoDai', { id: this.deleteHuoDaiId }, 'params').then(res => {
				uni.hideLoading();
				if (res.code == 0) {
					if (res.data) {
						this.$u.toast('删除成功');
						this.getAllHuoDaiByCustomerId();
					} else {
						this.$u.toast('删除失败');
					}
				}
			});
		},
		// 删除车队
		deleteFleetClick(args) {
			console.log(args.name, '车队id');
			this.deleteFleetId = args.name;
			this.deleteFleetShow = true;
			this.fleetData.forEach(item => {
				if (item.id == this.deleteFleetId) {
					this.deleteFleetContent = '确认删除车队' + item.name;
				}
			});
		},
		deleteFleetClose() {
			this.deleteFleetShow = false;
		},
		deleteFleetCancel() {
			this.deleteFleetShow = false;
		},
		deleteFleetConfirm() {
			this.deleteFleetShow = false;
			uni.showLoading({
				title: '加载中...'
			});
			this.$reqPost('deleteFleet', { id: this.deleteFleetId }, 'params').then(res => {
				console.log('删除车队', res);
				if (res.code == 0) {
					this.$u.toast('删除成功');
				}
				uni.hideLoading();
				this.getFleet();
			});
		},
		// 货代详情
		toFreightForwarderDetails(id) {
			uni.navigateTo({
				url: `/pages/customer-page/freight-forwarder-details/freight-forwarder-details`
			});
		},
		// 车队详情
		tofleetDetails(id) {
			uni.navigateTo({
				url: `/pages/customer-page/fleet-management/fleet-management?id=${id}`
			});
		},
		logout() {
			this.logoutShow = true;
		},
		logoutConfirm() {
			redirectLogin();
		},
		logoutCancel() {
			this.logoutShow = false;
		}
	}
};
</script>

<style lang="scss" scoped>
::v-deep.customer-my {
	width: 94%;
	margin: 0 auto;

	.huodai {
		.huodai-list {
			.u-swipe-action {
				.u-swipe-action-item {
					.u-swipe-action-item__right {
						.u-swipe-action-item__right__button {
							.u-swipe-action-item__right__button__wrapper {
								background-color: #f56c6c !important;
							}
						}
					}
				}
			}
		}
	}

	.fleet-container {
		.fleet-list {
			.u-swipe-action {
				.u-swipe-action-item {
					.u-swipe-action-item__right {
						.u-swipe-action-item__right__button {
							.u-swipe-action-item__right__button__wrapper {
								background-color: #f56c6c !important;
							}
						}
					}
				}
			}
		}
	}

	// 新建车队
	.addNewGroup {
		.u-popup {
			.u-popup__content {
				width: 94%;
				height: vww(160);
				border-radius: 1%;

				.title {
					width: 100%;
					text-align: center;
					font-size: 20px;

					.u-text {
						.u-text__value {
						}
					}
				}

				.addCarForm {
					width: 80%;
					margin: 0 auto vww(30);
				}

				.addCarButton {
					width: 40%;
					margin: 0 auto;
				}
			}
		}
	}
}
</style>
